@@ -61,7 +61,7 @@ except ImportError:  # pragma: no cover
 open = open  # allow monkey patching
 
 __pkgname__ = 'pip-licenses'
-__version__ = '3.4.0'
+__version__ = '3.5.1'
 __author__ = 'raimon'
 __license__ = 'MIT'
 __summary__ = ('Dump the software license list of '
@@ -215,13 +215,13 @@ def get_packages(args: "CustomNamespace"):
     ignore_pkgs_as_lower = [pkg.lower() for pkg in args.ignore_packages]
     pkgs_as_lower = [pkg.lower() for pkg in args.packages]
 
-    fail_on_licenses = None
+    fail_on_licenses = set()
     if args.fail_on:
-        fail_on_licenses = args.fail_on.split(";")
+        fail_on_licenses = set(args.fail_on.split(";"))
 
-    allow_only_licenses = None
+    allow_only_licenses = set()
     if args.allow_only:
-        allow_only_licenses = args.allow_only.split(";")
+        allow_only_licenses = set(args.allow_only.split(";"))
 
     for pkg in pkgs:
         pkg_name = pkg.project_name
@@ -237,28 +237,34 @@ def get_packages(args: "CustomNamespace"):
 
         pkg_info = get_pkg_info(pkg)
 
-        license_name = select_license_by_source(
+        license_names = select_license_by_source(
             args.from_,
             pkg_info['license_classifier'],
             pkg_info['license'])
 
-        if fail_on_licenses and license_name in fail_on_licenses:
-            sys.stderr.write("fail-on license {} was found for package "
-                             "{}:{}".format(
-                                license_name,
-                                pkg_info['name'],
-                                pkg_info['version'])
-                             )
-            sys.exit(1)
+        if fail_on_licenses:
+            failed_licenses = license_names.intersection(fail_on_licenses)
+            if failed_licenses:
+                sys.stderr.write(
+                    "fail-on license {} was found for package "
+                    "{}:{}".format(
+                        '; '.join(sorted(failed_licenses)),
+                        pkg_info['name'],
+                        pkg_info['version'])
+                )
+                sys.exit(1)
 
-        if allow_only_licenses and license_name not in allow_only_licenses:
-            sys.stderr.write("license {} not in allow-only licenses was found"
-                             " for package {}:{}".format(
-                                license_name,
-                                pkg_info['name'],
-                                pkg_info['version'])
-                             )
-            sys.exit(1)
+        if allow_only_licenses:
+            uncommon_licenses = license_names.difference(allow_only_licenses)
+            if len(uncommon_licenses) == len(license_names):
+                sys.stderr.write(
+                    "license {} not in allow-only licenses was found"
+                    " for package {}:{}".format(
+                        '; '.join(sorted(uncommon_licenses)),
+                        pkg_info['name'],
+                        pkg_info['version'])
+                )
+                sys.exit(1)
 
         yield pkg_info
 
@@ -271,11 +277,12 @@ def create_licenses_table(
         row = []
         for field in output_fields:
             if field == 'License':
-                license_str = select_license_by_source(
+                license_set = select_license_by_source(
                     args.from_, pkg['license_classifier'], pkg['license'])
+                license_str = '; '.join(sorted(license_set))
                 row.append(license_str)
             elif field == 'License-Classifier':
-                row.append(', '.join(pkg['license_classifier'])
+                row.append('; '.join(sorted(pkg['license_classifier']))
                            or LICENSE_UNKNOWN)
             elif field.lower() in pkg:
                 row.append(pkg[field.lower()])
@@ -287,8 +294,9 @@ def create_licenses_table(
 
 
 def create_summary_table(args: "CustomNamespace"):
-    counts = Counter(select_license_by_source(
-        args.from_, pkg['license_classifier'], pkg['license'])
+    counts = Counter(
+        '; '.join(sorted(select_license_by_source(
+            args.from_, pkg['license_classifier'], pkg['license'])))
         for pkg in get_packages(args))
 
     table = factory_styled_table_with_args(args, SUMMARY_FIELD_NAMES)
@@ -456,12 +464,12 @@ def find_license_from_classifier(message):
 
 
 def select_license_by_source(from_source, license_classifier, license_meta):
-    license_classifier_str = ', '.join(license_classifier) or LICENSE_UNKNOWN
+    license_classifier_set = set(license_classifier) or {LICENSE_UNKNOWN}
     if (from_source == FromArg.CLASSIFIER or
             from_source == FromArg.MIXED and len(license_classifier) > 0):
-        return license_classifier_str
+        return license_classifier_set
     else:
-        return license_meta
+        return {license_meta}
 
 
 def get_output_fields(args: "CustomNamespace"):
